# Replication Files for Improving the Science of Annotation for Natural Language Processing

## Overview
The files contained in this folder replicate the tables and figures presented in the manuscript. 

The raw datafiles were produced within the context of two experiments conducted in July of 2021 (Main Experiment) and in April of of 2022 (Follow-up Experiment). The goal of the experiments was to determine the most effective annotation procedures. 


### Background
In the main experiment, we empirically assess two competing approaches to human annotation. In the
*simple approach*, the annotation task is broken down into short and simple micro-tasks:
annotators view short text segments while considering one coding category at a time. In
the *complex approach*, annotators consider all codes at once and consecutively annotate
text segments within a full document. 

The study is situated within a broader educational research project focused on the22
efficacy of one-on-one coaching for improving teacher practice. The goal of the research is
to use text classification to automatically monitor the strategies employed by coaches in
their conversations with teachers and teachers-in-training. To this end, we ask annotators to code utterances for eight common strategies. These include: positive evaluation, observation, suggestion,
instruction, demonstration, anticipation, practice, and encouragement. In a single turn, a coach can employ as many as eight strategies or as few as zero. This means our project involves a multi-label classification task in which there are multiple labels and many can apply at once. 

### Main Experiment
Under the complex annotation procedure, annotators were asked to code one transcript at a time and to consider all coaching strategies at once. To this end, their coding
interface included one file per transcript. In each file, transcripts were formatted so
that each row was a turn-of-talk. Turns-of-talk were kept in the order in which they15
were spoken, including both coach speech and teacher-in-training speech. For each coach
utterance, annotators would select codes from a drop down menu containing the eight
coaching strategies and an option for “None of the above.” When appropriate, annotatators could select multiple codes. When annotators finished coding a transcript, they
would open the next file to continue coding the next transcript.

In the simple annotation scheme, annotators were asked to code for one coaching
strategy at a time. Thus, annotators were provided with one file per code (rather than
one file per transcript). Again, each row was a turn-of-talk. However, turns-of-talk were
presented in random order so that utterances were viewed with only the preceding teacher
turn of talk as context. Annotators were then asked to enter a zero or one indicating
whether the coach’s speech was an exemplar of the target code. Once annotators finished
coding all utterances for one coaching strategy, they would open the next file and code the same utterances for the next code. 

Annotators were randomly assigned to their starting condition (either the simple or
complex annotation procedure). After the first week of coding, annotators were instructed
to switch their method of annotation (from the simple to the complex, or vice versa) at
the beginning of each of the successive three weeks of coding.

### Follow-up experiment
We also conducted  a short follow-up experiment which only varies the context
provided to annotators. In both conditions, annotators code for all labels at once, but in
one condition ("in-context"), annotators view the utterance within the context of the full
transcript. In the other condition ("out-of-context"), annotators only view the preceding utterance. As in the previous design, annotators switched conditions each week. Only three annotators participated in the follow up experiment. 


## Software requirements
Python 3.10.0

The results were created using the following versions of the below packages: 
* pandas 1.4.0
* numpy 1.22.2
* matplotlib 3.5.1
* seaborn 0.11.2
* openpyxl 3.0.9
* statsmodels 0.13.1

The file requirements.txt lists this dependencies. Please run install -r requirements.txt as the first step. 

## Data availability
To run the files, replicators will need four files:

codes_wide.csv - Refers to the main experiment. An utterance ID linked to the codes produced by two annotators coding using the complex procedure coders (incontext_a and incontext_b columns) and two annotators coding using the simple procedure (out_context_a and out_context_b columns). Coders selected 0 or 1 for each potential code in the codebook (move and move_label columns). The correct code is denoted in the master column.


times.csv - Refers to the main experiment. Coder id linked to the total amount of time it took each coder to code of the utterances in a given week.  

codes_wide_followup.csv - Refers to the follow-up experiment. An utterance ID linked to the codes produced by two annotators coding using the complex procedure where utterances are presented in the order that they occured(incontext_a and incontext_b columns) and two annotators coding using the complex procedure where utterances are presented in random order(out_context_a and out_context_b columns). Coders selected 0 or 1 for each potential code in the codebook (move and move_label columns). 

times_follow_up.csv - Refers to the follow-up experiment. Coder id linked to the total amount of time it took each coder to code of the utterances in a given week. 

Note that the content of the utterances refered to in the raw data files have been removed so as to protect the privacy of the coaches and teachers who participated in the original study.

## Instructions

The files need to be organized into one main folder with three subfolders. All .py files should be in a folder named "code". All csv files should be in a folder named "data". All xlsx and eps files should be a folder named "results". 

Before running any files, the replicator will need to edit the start.py file so that the path in MAIN refers to their own directory pointing to the replication_files folder. 

The script files should be run in order from 01 to 09. 


## Description of programs
01_clean_for_analysis will reformat codes_wide.csv for analysis. 
02_analyze_times.py will use times.csv to create the single-case study figures with time as the outcome of interest in the main experiment.
03_analyze_accuracy_figures.py will create the single-case study figures with accuracy, recall, and precision as the outcome in the main experiment.
04_analyze_accuracy_models.py will create the tables with accuracy, recall and precision as the outcome in the main experiment. 
05_clean_for_analysis_followup.py will reformat codes_wide_followup.csv for analysis. 
06_analyze_times_followup.py will use times_followup.csv to create the single-case study figures with time as the outcome of interest in the follow-up experiment.
07_analyze_accuracy_figures_followup.py will create the single-case study figures with accuracy, recall, and precision as the outcome in the follow-up experiment.
08_analyze_accuracy_models_followup.py will create the tables with accuracy, recall and precision as the outcome in the follow-up experiment. 

All results are outputed to the results folder. 