# %%
import pandas as pd
import numpy as np
import matplotlib.pyplot as plt
from openpyxl import load_workbook


import statsmodels.formula.api as smf
import seaborn as sns


import start

label_list = ["Complex", "Simple", "Complex", "Simple", "Complex"]

# %%
df_long = pd.read_csv(start.DATA_PATH + "codes_long.csv")
df_wide = pd.read_csv(start.DATA_PATH + "codes_wide.csv")

# %% summarize in and out of context means
df_summary = (
    df_long[["week", "coder", "context", "precision", "recall", "accuracy", "code"]]
    .groupby(by=["week", "coder", "context"])
    .mean()
)

summary = df_summary.groupby(["context"]).mean()

# %% single case study figures
plt.style.use("seaborn")
sns.set_style("whitegrid")


def myplot(outcome: str, ylabel: str, saveas: str, ymin, ymax):
    fig, ax = plt.subplots()
    ax.plot(
        [1, 2, 3, 4],
        df_summary.xs(1, level=1, drop_level=False)[outcome],
        color="black",
        linestyle="solid",
        label="Annotator 1",
    )

    ax.plot(
        [2, 3, 4, 5],
        df_summary.xs(2, level=1, drop_level=False)[outcome],
        color="gray",
        linestyle="solid",
        label="Annotator 2",
    )

    ax.plot(
        [1, 2, 3, 4],
        df_summary.xs(3, level=1, drop_level=False)[outcome],
        color="black",
        linestyle="dashed",
        label="Annotator 3",
    )

    ax.plot(
        [2, 3, 4, 5],
        df_summary.xs(4, level=1, drop_level=False)[outcome],
        color="gray",
        linestyle="dashed",
        label="Annotator 4",
    )

    plt.xlabel("Annotation Procedure")
    plt.ylabel(ylabel)
    plt.ylim(ymin, ymax)
    plt.xticks([1, 2, 3, 4, 5], labels=label_list)
    plt.legend()
    plt.savefig(start.RESULTS_PATH + saveas)


myplot("accuracy", "Accuracy", saveas="single_case_accuracy.eps", ymin=0.9, ymax=1)
myplot("precision", "Precision", saveas="single_case_precision.eps", ymin=0.5, ymax=1)
myplot("recall", "Recall", saveas="single_case_recall.eps", ymin=0.5, ymax=1)
